# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPolygonalPatches3D.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tracking import TrackedPolygonalPatch3D_pb2 as rst_dot_tracking_dot_TrackedPolygonalPatch3D__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPolygonalPatches3D.proto',
  package='rst.tracking',
  syntax='proto2',
  serialized_pb=_b('\n,rst/tracking/TrackedPolygonalPatches3D.proto\x12\x0crst.tracking\x1a*rst/tracking/TrackedPolygonalPatch3D.proto\"Q\n\x19TrackedPolygonalPatches3D\x12\x34\n\x05patch\x18\x01 \x03(\x0b\x32%.rst.tracking.TrackedPolygonalPatch3DB\x1f\x42\x1dTrackedPolygonalPatches3DType')
  ,
  dependencies=[rst_dot_tracking_dot_TrackedPolygonalPatch3D__pb2.DESCRIPTOR,])




_TRACKEDPOLYGONALPATCHES3D = _descriptor.Descriptor(
  name='TrackedPolygonalPatches3D',
  full_name='rst.tracking.TrackedPolygonalPatches3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='patch', full_name='rst.tracking.TrackedPolygonalPatches3D.patch', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=187,
)

_TRACKEDPOLYGONALPATCHES3D.fields_by_name['patch'].message_type = rst_dot_tracking_dot_TrackedPolygonalPatch3D__pb2._TRACKEDPOLYGONALPATCH3D
DESCRIPTOR.message_types_by_name['TrackedPolygonalPatches3D'] = _TRACKEDPOLYGONALPATCHES3D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackedPolygonalPatches3D = _reflection.GeneratedProtocolMessageType('TrackedPolygonalPatches3D', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDPOLYGONALPATCHES3D,
  __module__ = 'rst.tracking.TrackedPolygonalPatches3D_pb2'
  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPolygonalPatches3D)
  ))
_sym_db.RegisterMessage(TrackedPolygonalPatches3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\035TrackedPolygonalPatches3DType'))
# @@protoc_insertion_point(module_scope)
